package handlers

import (
	"bytes"
	"encoding/json"
	"fmt"
	"io/ioutil"
	"net/http"

	"github.com/gofiber/fiber/v2"

	"gitlab.larvit.se/power-plan/auth-ui/src/views"
)

func (h Handlers) Register(c *fiber.Ctx) error {
	c.Set(fiber.HeaderContentType, fiber.MIMETextHTML)
	return c.SendString(views.Register())
}

type NewUser struct {
	Username       string
	Password       string
	RepeatPassword string
}

func (h Handlers) RegisterPost(c *fiber.Ctx) error {
	c.Set(fiber.HeaderContentType, fiber.MIMETextHTML)
	newUser := new(NewUser)

	err := c.BodyParser(newUser)
	if err != nil {
		h.Log.Debug("Invalid input data", "err", err.Error())
		c.Status(400)
	}

	fmt.Printf("newUser: %v", newUser)

	jsonPayload, err := json.Marshal(newUser)
	if err != nil {
		h.Log.Error("Could not marshal newUser struct", "err", err.Error())
		return c.Status(500).SendString(views.Error500())
	}

	req, err := http.NewRequest("POST", "http://localhost:4000/account", bytes.NewBuffer(jsonPayload))
	if err != nil {
		h.Log.Error("Could not create POST request", "err", err.Error())
		return c.Status(500).SendString(views.Error500())
	}
	req.Header.Set("Content-Type", "application/json")

	httpClient := &http.Client{}
	res, err := httpClient.Do(req)
	if err != nil {
		h.Log.Error("Could not call backend API", "err", err.Error())
		return c.Status(500).SendString(views.Error500())
	}
	defer res.Body.Close()

	h.Log.Debug("API res status", "status", res.Status)

	body, err := ioutil.ReadAll(res.Body)
	if err != nil {
		h.Log.Error("Could not read res body", "err", err.Error())
		return c.Status(500).SendString(views.Error500())
	}

	fmt.Println("response Body:", string(body))

	return c.SendString(views.Register())
}
