package main

import (
	"os"
	"time"

	"github.com/gofiber/fiber/v2"
	"github.com/joho/godotenv"
	h "gitlab.larvit.se/power-plan/auth-ui/src/handlers"
	"gitlab.larvit.se/power-plan/auth-ui/src/utils"
)

func main() {
	log := utils.GetLog()

	err := godotenv.Load()
	if err != nil {
		log.Warn("Error loading .env file, this could be ok if the env file does not exist", "err", err.Error())
	}

	if os.Getenv("JWT_SHARED_SECRET") == "changeMe" {
		log.Error("JWT_SHARED_SECRET ENV is not set, using very insecure \"changeMe\"")
	}
	if os.Getenv("ADMIN_API_KEY") == "changeMe" {
		log.Error("ADMIN_API_KEY ENV is not set, using very insecure \"changeMe\"")
	}
	jwtKey := []byte(os.Getenv("JWT_SHARED_SECRET"))

	app := fiber.New()

	handlers := h.Handlers{JwtKey: jwtKey, Log: log}

	// Log all requests
	app.Use(handlers.LogReq)

	// Static files
	app.Static("/", "./src/public")

	app.Get("/", handlers.Index)

	app.Get("/register", handlers.Register)
	app.Post("/register", handlers.RegisterPost)

	log.Info("Trying to start web server", "PORT", os.Getenv("PORT"))

	webBindHost := ":" + os.Getenv("PORT")
	err = app.Listen(webBindHost)
	for err != nil {
		log.Error("Could not start web server", "err", err.Error(), "webBindHost", webBindHost)
		time.Sleep(1 * time.Second)
		err = app.Listen(webBindHost)
	}

	log.Info("Webb server closed, shutting down")
}
